FlutterLinkmeSdkWeb class

Inheritance

Constructors

FlutterLinkmeSdkWeb()

Properties

hashCode → int
The hash code for this object.
no setterinherited
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

claimDeferredIfAvailable() → Future<LinkMePayload?>
override
configure(LinkMeConfig config) → Future<void>
override
debugVisitUrl(String url, {Map<String, String>? headers}) → Future<int?>
override
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdvertisingConsent(bool granted) → Future<void>
override
setReady() → Future<void>
override
setUserId(String? userId) → Future<void>
override
toString() → String
A string representation of this object.
inherited
track(String event, {Map<String, dynamic>? properties}) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void